aboutsummaryrefslogtreecommitdiff
path: root/tests
diff options
context:
space:
mode:
Diffstat (limited to 'tests')
-rw-r--r--tests/unit/test_heatmaps.py (renamed from tests/unit/computations/test_heatmap.py)4
1 files changed, 2 insertions, 2 deletions
diff --git a/tests/unit/computations/test_heatmap.py b/tests/unit/test_heatmaps.py
index 156af45..265d5a8 100644
--- a/tests/unit/computations/test_heatmap.py
+++ b/tests/unit/test_heatmaps.py
@@ -1,6 +1,6 @@
"""Module contains tests for gn3.computations.heatmap"""
from unittest import TestCase
-from gn3.computations.heatmap import (
+from gn3.heatmaps import (
cluster_traits,
export_trait_data,
compute_traits_order,
@@ -1,6 +1,6 @@
-"""Module contains tests for gn3.computations.heatmap"""
+"""Module contains tests for gn3.heatmaps.heatmaps"""
from unittest import TestCase